@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2010 Siyan Panayotov <xsisqox@gmail.com>
+ * Copyright © 2009-2012 Siyan Panayotov <xsisqox@gmail.com>
  *
  * This file is part of Viewnior.
  *
@@ -33,6 +33,7 @@
 static gchar **files = NULL;     //array of files specified to be opened
 static gboolean version = FALSE;
 static gboolean slideshow = FALSE;
+static gboolean fullscreen = FALSE;
 
 /* List of option entries
  * The only option is for specifying file to be opened. */
@@ -40,6 +41,7 @@ static GOptionEntry opt_entries[] = {
     {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &files, NULL, "[FILE]"},
     {"version", 0, 0, G_OPTION_ARG_NONE, &version, NULL, NULL},
     {"slideshow", 0, 0, G_OPTION_ARG_NONE, &slideshow, NULL, NULL},
+    {"fullscreen", 0, 0, G_OPTION_ARG_NONE, &fullscreen, NULL, NULL},
     {NULL}
 };
 
@@ -120,7 +122,9 @@ main (int argc, char *argv[])
             vnr_window_set_list(VNR_WINDOW(window), file_list, TRUE);
         }
     }
+    
     VNR_WINDOW(window)->prefs->start_slideshow = slideshow;
+    VNR_WINDOW(window)->prefs->start_fullscreen = fullscreen;
     if ( VNR_WINDOW(window)->prefs->start_maximized ) {
     	gtk_window_maximize(window);
     }
