@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2010 Siyan Panayotov <xsisqox@gmail.com>
+ * Copyright © 2009-2012 Siyan Panayotov <xsisqox@gmail.com>
  *
  * This file is part of Viewnior.
  *
@@ -76,6 +76,13 @@ change_zoom_mode_cb (GtkComboBox *widget, gpointer user_data)
     vnr_prefs_save(VNR_PREFS(user_data));
 }
 
+static void
+change_desktop_env_cb (GtkComboBox *widget, gpointer user_data)
+{
+    VNR_PREFS(user_data)->desktop = gtk_combo_box_get_active(widget);
+    vnr_prefs_save(VNR_PREFS(user_data));
+}
+
 static void
 change_jpeg_quality_cb (GtkRange *range, gpointer user_data)
 {
@@ -143,6 +150,7 @@ static void
 vnr_prefs_set_default(VnrPrefs *prefs)
 {
     prefs->zoom = VNR_PREFS_ZOOM_SMART;
+    prefs->desktop = VNR_PREFS_DESKTOP_GNOME3;
     prefs->show_hidden = FALSE;
     prefs->fit_on_fullscreen = TRUE;
     prefs->smooth_images = TRUE;
@@ -157,6 +165,8 @@ vnr_prefs_set_default(VnrPrefs *prefs)
     prefs->show_toolbar = TRUE;
     prefs->start_maximized = FALSE;
     prefs->start_slideshow = FALSE;
+    prefs->start_fullscreen = FALSE;
+    prefs->auto_resize = FALSE;
 }
 
 static GtkWidget *
@@ -170,7 +180,9 @@ build_dialog (VnrPrefs *prefs)
     GtkToggleButton *show_hidden;
     GtkToggleButton *fit_on_fullscreen;
     GtkBox *zoom_mode_box;
+    GtkBox *desktop_box;
     GtkComboBox *zoom_mode;
+    GtkComboBox *desktop_env;
     GtkToggleButton *smooth_images;
     GtkToggleButton *confirm_delete;
     GtkToggleButton *reload_on_save;
@@ -255,6 +267,22 @@ build_dialog (VnrPrefs *prefs)
 
     g_signal_connect(G_OBJECT(zoom_mode), "changed", G_CALLBACK(change_zoom_mode_cb), prefs);
 
+    /* Desktop combo box */
+    desktop_box = GTK_BOX (gtk_builder_get_object (builder, "desktop_box"));
+
+    desktop_env = (GtkComboBox*) gtk_combo_box_new_text();
+    gtk_combo_box_append_text(desktop_env, "GNOME 2");
+    gtk_combo_box_append_text(desktop_env, "GNOME 3");
+    gtk_combo_box_append_text(desktop_env, "XFCE");
+    gtk_combo_box_append_text(desktop_env, "LXDE");
+    gtk_combo_box_append_text(desktop_env, "FluxBox");
+    gtk_combo_box_set_active(desktop_env, prefs->desktop);
+
+    gtk_box_pack_end (desktop_box, GTK_WIDGET(desktop_env), FALSE, FALSE, 0);
+    gtk_widget_show(GTK_WIDGET(desktop_env));
+
+    g_signal_connect(G_OBJECT(desktop_env), "changed", G_CALLBACK(change_desktop_env_cb), prefs);
+
     /* Behavior combo boxes */
     behavior_table = GTK_TABLE (gtk_builder_get_object (builder, "behavior_table"));
 
@@ -321,6 +349,7 @@ vnr_prefs_load (VnrPrefs *prefs)
     }
 
     prefs->zoom = g_key_file_get_integer (conf, "prefs", "zoom-mode", &error);
+    prefs->desktop = g_key_file_get_integer (conf, "prefs", "desktop", &error);
     prefs->fit_on_fullscreen = g_key_file_get_boolean (conf, "prefs", "fit-on-fullscreen", &error);
     prefs->show_hidden = g_key_file_get_boolean (conf, "prefs", "show-hidden", &error);
     prefs->smooth_images = g_key_file_get_boolean (conf, "prefs", "smooth-images", &error);
@@ -329,6 +358,7 @@ vnr_prefs_load (VnrPrefs *prefs)
     prefs->show_toolbar = g_key_file_get_boolean (conf, "prefs", "show-toolbar", &error);
     prefs->start_maximized = g_key_file_get_boolean (conf, "prefs", "start-maximized", &error);
     prefs->slideshow_timeout = g_key_file_get_integer (conf, "prefs", "slideshow-timeout", &error);
+    prefs->auto_resize = g_key_file_get_boolean (conf, "prefs", "auto-resize", &error);
     prefs->behavior_wheel = g_key_file_get_integer (conf, "prefs", "behavior-wheel", &error);
     prefs->behavior_click = g_key_file_get_integer (conf, "prefs", "behavior-click", &error);
     prefs->behavior_modify = g_key_file_get_integer (conf, "prefs", "behavior-modify", &error);
@@ -407,6 +437,7 @@ vnr_prefs_save (VnrPrefs *prefs)
 
     conf = g_key_file_new();
     g_key_file_set_integer (conf, "prefs", "zoom-mode", prefs->zoom);
+    g_key_file_set_integer (conf, "prefs", "desktop", prefs->desktop);
     g_key_file_set_boolean (conf, "prefs", "fit-on-fullscreen", prefs->fit_on_fullscreen);
     g_key_file_set_boolean (conf, "prefs", "show-hidden", prefs->show_hidden);
     g_key_file_set_boolean (conf, "prefs", "smooth-images", prefs->smooth_images);
@@ -415,6 +446,7 @@ vnr_prefs_save (VnrPrefs *prefs)
     g_key_file_set_boolean (conf, "prefs", "show-toolbar", prefs->show_toolbar);
     g_key_file_set_boolean (conf, "prefs", "start-maximized", prefs->start_maximized);
     g_key_file_set_integer (conf, "prefs", "slideshow-timeout", prefs->slideshow_timeout);
+    g_key_file_set_boolean (conf, "prefs", "auto-resize", prefs->auto_resize);
     g_key_file_set_integer (conf, "prefs", "behavior-wheel", prefs->behavior_wheel);
     g_key_file_set_integer (conf, "prefs", "behavior-click", prefs->behavior_click);
     g_key_file_set_integer (conf, "prefs", "behavior-modify", prefs->behavior_modify);
