@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2010 Siyan Panayotov <xsisqox@gmail.com>
+ * Copyright © 2009-2012 Siyan Panayotov <xsisqox@gmail.com>
  *
  * This file is part of Viewnior.
  *
@@ -44,6 +44,14 @@ typedef enum{
     VNR_PREFS_ZOOM_LAST_USED,
 } VnrPrefsZoom;
 
+typedef enum{
+    VNR_PREFS_DESKTOP_GNOME2,
+    VNR_PREFS_DESKTOP_GNOME3,
+    VNR_PREFS_DESKTOP_XFCE,
+    VNR_PREFS_DESKTOP_LXDE,
+    VNR_PREFS_DESKTOP_FLUXBOX,
+} VnrPrefsDesktop;
+
 typedef enum{
     VNR_PREFS_WHEEL_NAVIGATE ,
     VNR_PREFS_WHEEL_ZOOM ,
@@ -66,6 +74,7 @@ struct _VnrPrefs {
     GObject parent;
 
     VnrPrefsZoom zoom;
+    VnrPrefsDesktop desktop;
     VnrPrefsWheel behavior_wheel;
     VnrPrefsClick behavior_click;
     VnrPrefsModify behavior_modify;
@@ -77,6 +86,8 @@ struct _VnrPrefs {
     gboolean show_toolbar;
     gboolean start_maximized;
     gboolean start_slideshow;
+    gboolean start_fullscreen;
+    gboolean auto_resize;
     int slideshow_timeout;
     int jpeg_quality;
     int png_compression;
