@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2010 Siyan Panayotov <xsisqox@gmail.com>
+ * Copyright © 2009-2012 Siyan Panayotov <xsisqox@gmail.com>
  *
  * This file is part of Viewnior.
  *
@@ -16,7 +16,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Viewnior.  If not, see <http://www.gnu.org/licenses/>.
  */
-
+ 
 #include <libintl.h>
 #include <glib/gi18n.h>
 #define _(String) gettext (String)
@@ -25,10 +25,8 @@
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#ifdef HAVE_WALLPAPER
-#include <gconf/gconf-client.h>
-#endif /* HAVE_WALLPAPER */
 #include <errno.h>
+#include <sys/wait.h>
 #include "vnr-window.h"
 #include "uni-scroll-win.h"
 #include "uni-anim-view.h"
@@ -60,34 +58,28 @@ static gboolean fullscreen_motion_cb(GtkWidget * widget, GdkEventMotion * ev, Vn
 static void open_with_launch_application_cb (GtkAction *action, VnrWindow *window);
 
 const gchar *ui_definition = "<ui>"
-  "<menubar name=\"MainMenu\">"
-    "<menu action=\"File\">"
-      "<menuitem action=\"FileOpen\"/>"
-      "<menuitem action=\"FileOpenDir\"/>"
-      "<menu action=\"FileOpenWith\">"
-         "<placeholder name=\"AppEntries\"/>"
-      "</menu>"
-      "<separator/>"
-      "<menuitem action=\"FileSave\"/>"
-      "<menuitem action=\"FileReload\"/>"
-      "<separator/>"
-      "<menuitem action=\"FileProperties\"/>"
-      "<separator/>"
-      "<menuitem action=\"FileClose\"/>"
+  "<popup name=\"MainMenu\">"
+    "<menuitem action=\"FileOpen\"/>"
+    "<menuitem action=\"FileOpenDir\"/>"
+    "<menu action=\"FileOpenWith\">"
+       "<placeholder name=\"AppEntries\"/>"
     "</menu>"
+    "<separator/>"
+    "<menuitem action=\"FileSave\"/>"
+    "<menuitem action=\"FileReload\"/>"
+    "<menuitem action=\"FileProperties\"/>"
+    "<separator/>"
     "<menu action=\"Edit\">"
       "<menuitem action=\"FileDelete\"/>"
       "<separator/>"
-      "<menuitem action=\"EditPreferences\"/>"
     "</menu>"
     "<menu action=\"View\">"
-      "<menuitem action=\"ViewToolbar\"/>"
-      "<separator/>"
       "<menuitem action=\"ViewZoomIn\"/>"
       "<menuitem action=\"ViewZoomOut\"/>"
       "<menuitem action=\"ViewZoomNormal\"/>"
       "<menuitem action=\"ViewZoomFit\"/>"
       "<separator/>"
+      "<menuitem action=\"ViewToolbar\"/>"
       "<menuitem name=\"Fullscreen\" action=\"ViewFullscreen\"/>"
       "<menuitem name=\"Slideshow\" action=\"ViewSlideshow\"/>"
       "<separator/>"
@@ -103,17 +95,12 @@ const gchar *ui_definition = "<ui>"
       "<menuitem action=\"ImageCrop\"/>"
       "<placeholder name=\"WallpaperEntry\"/>"
     "</menu>"
-    "<menu action=\"Go\">"
-      "<menuitem name=\"GoPrevious\" action=\"GoPrevious\"/>"
-      "<menuitem name=\"GoNext\" action=\"GoNext\"/>"
-      "<separator/>"
-      "<menuitem name=\"GoFirst\" action=\"GoFirst\"/>"
-      "<menuitem name=\"GoLast\" action=\"GoLast\"/>"
-    "</menu>"
-    "<menu action=\"Help\">"
-      "<menuitem action=\"HelpAbout\"/>"
-    "</menu>"
-  "</menubar>"
+    "<separator/>"
+    "<menuitem action=\"EditPreferences\"/>"
+    "<separator/>"
+    "<menuitem action=\"HelpAbout\"/>"
+    "<menuitem action=\"FileClose\"/>"
+  "</popup>"
   "<toolbar name=\"Toolbar\">"
     "<toolitem action=\"GoPrevious\"/>"
     "<toolitem action=\"GoNext\"/>"
@@ -125,6 +112,8 @@ const gchar *ui_definition = "<ui>"
     "<separator/>"
     "<toolitem action=\"ImageRotateCCW\"/>"
     "<toolitem action=\"ImageRotateCW\"/>"
+    "<separator expand=\"true\"/>"
+    "<toolitem action=\"Properties\"/>"
   "</toolbar>"
   "<popup name=\"PopupMenu\">"
     "<menuitem name=\"GoPrevious\" action=\"GoPrevious\"/>"
@@ -139,6 +128,7 @@ const gchar *ui_definition = "<ui>"
     "<menuitem action=\"ViewZoomNormal\"/>"
     "<placeholder name=\"WallpaperEntry\"/>"
     "<separator/>"
+    "<menuitem name=\"Toolbar\" action=\"ViewToolbar\"/>"
     "<menuitem name=\"Fullscreen\" action=\"ViewFullscreen\"/>"
     "<separator/>"
     "<menuitem action=\"FileProperties\"/>"
@@ -150,16 +140,15 @@ const gchar *ui_definition = "<ui>"
 "</ui>";
 
 
-#ifdef HAVE_WALLPAPER
 const gchar *ui_definition_wallpaper = "<ui>"
-  "<menubar name=\"MainMenu\">"
+  "<popup name=\"MainMenu\">"
     "<menu action=\"Image\">"
       "<placeholder name=\"WallpaperEntry\">"
         "<separator/>"
         "<menuitem name=\"Wallpaper\" action=\"SetAsWallpaper\"/>"
       "</placeholder>"
     "</menu>"
-  "</menubar>"
+  "</popup>"
   "<popup name=\"PopupMenu\">"
     "<placeholder name=\"WallpaperEntry\">"
       "<separator/>"
@@ -167,7 +156,6 @@ const gchar *ui_definition_wallpaper = "<ui>"
     "</placeholder>"
   "</popup>"
 "</ui>";
-#endif /* HAVE_WALLPAPER */
 
 /*************************************************************/
 /***** Private actions ***************************************/
@@ -259,7 +247,7 @@ vnr_window_update_openwith_menu (VnrWindow *window)
 
         gtk_ui_manager_add_ui (window->ui_mngr,
                         window->open_with_menu_id,
-                        "/MainMenu/File/FileOpenWith/AppEntries",
+                        "/MainMenu/FileOpenWith/AppEntries",
                         name,
                         name,
                         GTK_UI_MANAGER_MENUITEM,
@@ -912,6 +900,40 @@ save_image_cb (GtkWidget *widget, VnrWindow *window)
         vnr_properties_dialog_update(VNR_PROPERTIES_DIALOG(window->props_dlg));
 }
 
+static void
+vnr_window_main_menu_position (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer user_data)
+{
+	VnrWindow *window = VNR_WINDOW(user_data);
+	GtkWidget *button = GTK_WIDGET(gtk_ui_manager_get_widget (window->ui_mngr, "/Toolbar/Properties"));
+	GdkWindow *gdk_window = gtk_widget_get_window(button);
+	
+	gdk_window_get_position(gdk_window, x, y);
+	
+	// in maximuzed and fullscreen states gdk_window_get_position returns 0 
+	if ( *x == 0 && gtk_widget_get_visible ( get_fs_controls(window)) ) {
+		*x -= get_fs_controls(window)->allocation.width;
+	} 
+	
+	*x += window->toolbar->allocation.width - button->allocation.width;
+	*y += button->allocation.height;
+}
+
+static void
+vnr_window_cmd_open_menu (GtkToggleAction *action, VnrWindow *window)
+{
+	if( !gtk_toggle_action_get_active (action)) {
+		return;
+	}
+	gtk_menu_popup(GTK_MENU(window->menu_bar), NULL, NULL, vnr_window_main_menu_position, window, 0, gtk_get_current_event_time());
+	return;
+}
+
+static void
+vnr_window_cmd_main_menu_hidden (GtkWidget *widget, gpointer user_data)
+{
+	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(gtk_ui_manager_get_widget (VNR_WINDOW(user_data)->ui_mngr, "/Toolbar/Properties")), FALSE);
+}
+
 static void
 leave_fs_cb (GtkButton *button, VnrWindow *window)
 {
@@ -948,6 +970,8 @@ window_realize_cb(GtkWidget *widget, gpointer user_data)
 			VNR_WINDOW(widget)->mode = VNR_WINDOW_MODE_NORMAL;
 			allow_slideshow(VNR_WINDOW(widget));
 			start_slideshow(VNR_WINDOW(widget));
+		} else if ( VNR_WINDOW(widget)->prefs->start_fullscreen && VNR_WINDOW(widget)->file_list != NULL ) {
+			vnr_window_fullscreen(VNR_WINDOW(widget));
 		}
     }
 }
@@ -967,6 +991,15 @@ window_change_state_cb (GtkWidget * widget, GdkEventWindowState * event, gpointe
 	return TRUE;
 }
 
+
+static void
+window_destroy_cb (GtkObject *object, gpointer user_data)
+{
+    vnr_window_save_accel_map();
+    vnr_prefs_save(VNR_WINDOW(object)->prefs);
+	gtk_main_quit();
+}
+
 static void
 zoom_changed_cb (UniImageView *view, VnrWindow *window)
 {
@@ -1111,16 +1144,22 @@ vnr_window_cmd_prev (GtkAction *action, gpointer user_data)
 static void
 vnr_window_cmd_resize (GtkToggleAction *action, VnrWindow *window)
 {
-	if ( action != NULL && !gtk_toggle_action_get_active(action) )
-		return;
+    if ( action != NULL && !gtk_toggle_action_get_active(action) ) {
+        window->prefs->auto_resize = FALSE;
+        return;
+    }
 	
     gint img_h, img_w;          /* Width and Height of the pixbuf */
 
     img_w = window->current_image_width;
     img_h = window->current_image_height;
+    
+    if ( img_w == 0 || img_h == 0 )
+        return;
 
+    window->prefs->auto_resize = TRUE;
+    
     vnr_tools_fit_to_size (&img_w, &img_h, window->max_width, window->max_height);
-
     gtk_window_resize (GTK_WINDOW (window), img_w, img_h + window->menus->allocation.height);
 }
 
@@ -1219,7 +1258,7 @@ vnr_window_cmd_about (GtkAction *action, VnrWindow *window)
     gtk_show_about_dialog (GTK_WINDOW (window),
                    "program-name", "Viewnior",
                    "version", VERSION,
-                   "copyright", "Copyright \xc2\xa9 2009-2010 Siyan Panayotov <xsisqox@gmail.com>",
+                   "copyright", "Copyright \xc2\xa9 2009-2012 Siyan Panayotov <xsisqox@gmail.com>",
                    "comments",_("Elegant Image Viewer"),
                    "authors", authors,
                    "logo-icon-name", "viewnior",
@@ -1230,17 +1269,60 @@ vnr_window_cmd_about (GtkAction *action, VnrWindow *window)
                    NULL);
 }
 
-#ifdef HAVE_WALLPAPER
 static void
 vnr_set_wallpaper(GtkAction *action, VnrWindow *win)
 {
-    gconf_client_set_string (win->client,
-                 "/desktop/gnome/background/picture_filename",
-                 VNR_FILE(win->file_list->data)->path,
-                 NULL);
-
+	pid_t pid;
+	
+	pid = fork();
+	
+	if ( pid == 0 ) {
+		gchar * tmp;
+		
+		switch(win->prefs->desktop) {
+			case VNR_PREFS_DESKTOP_GNOME2:
+				execlp("gconftool-2", "gconftool-2", 
+						"--set", "/desktop/gnome/background/picture_filename", 
+						"--type", "string", 
+						VNR_FILE(win->file_list->data)->path, 
+						NULL);
+				break;
+			case VNR_PREFS_DESKTOP_GNOME3:
+				tmp = g_strdup_printf("file://%s", VNR_FILE(win->file_list->data)->path);
+				execlp("gsettings", "gsettings", 
+						"set", "org.gnome.desktop.background", 
+						"picture-uri", tmp, 
+						NULL);
+				break;
+			case VNR_PREFS_DESKTOP_XFCE:
+				tmp = g_strdup_printf("/backdrop/screen%d/monitor0/image-path", 
+										gdk_screen_get_number(gtk_widget_get_screen(GTK_WIDGET(win))));
+				execlp("xfconf-query", "xfconf-query", 
+						"-c", "xfce4-desktop",
+						"-p", tmp, 
+						"--type", "string", 
+						"--set",
+						VNR_FILE(win->file_list->data)->path, 
+						NULL);
+				break;
+			case VNR_PREFS_DESKTOP_LXDE:
+				execlp("pcmanfm", "pcmanfm", 
+						"--set-wallpaper",
+						VNR_FILE(win->file_list->data)->path, 
+						NULL);
+				break;
+			case VNR_PREFS_DESKTOP_FLUXBOX:
+				execlp("fbsetbg", "fbsetbg", 
+						"-f", VNR_FILE(win->file_list->data)->path, 
+						NULL);
+				break;
+			default:
+				_exit(0);	
+		}
+	} else {
+		wait(NULL);	
+	}
 }
-#endif /* HAVE_WALLPAPER */
 
 static void
 vnr_window_cmd_fullscreen (GtkAction *action, VnrWindow *window)
@@ -1374,14 +1456,14 @@ vnr_window_cmd_delete(GtkAction *action, VnrWindow *window)
         }
         else
         {
-            GList *new, *next;
+            GList *next;
 
             next = g_list_next(window->file_list);
             if(next == NULL)
                 next = g_list_first(window->file_list);
 
             if(g_list_length(g_list_first(window->file_list)) != 1)
-                new = g_list_delete_link (window->file_list, window->file_list);
+                window->file_list = g_list_delete_link (window->file_list, window->file_list);
             else
             {
                 g_list_free(window->file_list);
@@ -1393,6 +1475,7 @@ vnr_window_cmd_delete(GtkAction *action, VnrWindow *window)
                 vnr_window_close(window);
                 gtk_action_group_set_sensitive(window->actions_collection, FALSE);
                 deny_slideshow(window);
+                vnr_window_set_list(window, NULL, FALSE);
                 vnr_message_area_show(VNR_MESSAGE_AREA (window->msg_area), TRUE,
                                       _("The given locations contain no images."),
                                       TRUE);
@@ -1525,13 +1608,17 @@ static const GtkActionEntry action_entry_save[] = {
       G_CALLBACK (save_image_cb) },
 };
 
-#ifdef HAVE_WALLPAPER
+static const GtkToggleActionEntry toggle_entry_properties[] = {
+    { "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"), NULL,
+      N_("Properties"),
+      G_CALLBACK (vnr_window_cmd_open_menu) },
+};
+
 static const GtkActionEntry action_entry_wallpaper[] = {
     { "SetAsWallpaper", NULL, N_("Set as _Wallpaper"), "<control>F8",
       N_("Set the selected image as the desktop background"),
       G_CALLBACK (vnr_set_wallpaper) },
 };
-#endif /* HAVE_WALLPAPER */
 
 static const GtkActionEntry action_entries_image[] = {
     { "FileOpenWith", NULL, N_("Open _With"), NULL,
@@ -1732,7 +1819,7 @@ vnr_window_drag_data_received (GtkWidget *widget,
     if (!gtk_targets_include_uri (&selection_data->target, 1))
         return;
 
-    if (context->suggested_action == GDK_ACTION_COPY)
+    if (context->suggested_action == GDK_ACTION_COPY || context->suggested_action == GDK_ACTION_ASK)
     {
         uri_list = vnr_tools_parse_uri_string_list_to_file_list ((gchar *) selection_data->data);
 
@@ -1751,20 +1838,10 @@ vnr_window_drag_data_received (GtkWidget *widget,
     }
 }
 
-static void
-vnr_window_finalize (GObject *object)
-{
-    vnr_window_save_accel_map();
-    G_OBJECT_CLASS (vnr_window_parent_class)->finalize (object);
-}
-
 static void
 vnr_window_class_init (VnrWindowClass * klass)
 {
     GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
-    GObjectClass *g_object_class = (GObjectClass *) klass;
-
-    g_object_class->finalize = vnr_window_finalize;
 
     widget_class->key_press_event = vnr_window_key_press;
     widget_class->drag_data_received = vnr_window_drag_data_received;
@@ -1831,6 +1908,20 @@ vnr_window_init (VnrWindow * window)
     gtk_ui_manager_insert_action_group (window->ui_mngr,
                                         window->action_save, 0);
 
+    window->action_properties = gtk_action_group_new("MenuActionProperties");
+
+
+    gtk_action_group_set_translation_domain (window->action_properties,
+                                             GETTEXT_PACKAGE);
+
+    gtk_action_group_add_toggle_actions (window->action_properties,
+                                  toggle_entry_properties,
+                                  G_N_ELEMENTS (toggle_entry_properties),
+                                  window);
+
+    gtk_ui_manager_insert_action_group (window->ui_mngr,
+                                        window->action_properties, 0);
+
     window->actions_static_image = gtk_action_group_new("MenuActionsStaticImage");
 
 
@@ -1904,34 +1995,26 @@ vnr_window_init (VnrWindow * window)
             g_error_free (error);
     }
 
+    window->action_wallpaper = gtk_action_group_new("ActionWallpaper");
 
-#ifdef HAVE_WALLPAPER
-    window->client = gconf_client_get_default ();
+    gtk_action_group_set_translation_domain (window->action_wallpaper,
+                                             GETTEXT_PACKAGE);
 
-    if(gconf_client_dir_exists( window->client, "/desktop/gnome/background", NULL))
-    {
-        window->action_wallpaper = gtk_action_group_new("ActionWallpaper");
+    gtk_action_group_add_actions (window->action_wallpaper,
+                                  action_entry_wallpaper,
+                                  G_N_ELEMENTS (action_entry_wallpaper),
+                                  window);
 
-        gtk_action_group_set_translation_domain (window->action_wallpaper,
-                                                 GETTEXT_PACKAGE);
+    gtk_ui_manager_insert_action_group (window->ui_mngr,
+                                        window->action_wallpaper, 0);
 
-        gtk_action_group_add_actions (window->action_wallpaper,
-                                      action_entry_wallpaper,
-                                      G_N_ELEMENTS (action_entry_wallpaper),
-                                      window);
-
-        gtk_ui_manager_insert_action_group (window->ui_mngr,
-                                            window->action_wallpaper, 0);
-
-        if (!gtk_ui_manager_add_ui_from_string (window->ui_mngr,
-                                                ui_definition_wallpaper, -1,
-                                                &error)) {
-                g_error ("building menus failed: %s\n", error->message);
-                g_error_free (error);
-        }
-        gtk_action_group_set_sensitive(window->action_wallpaper, FALSE);
+    if (!gtk_ui_manager_add_ui_from_string (window->ui_mngr,
+                                            ui_definition_wallpaper, -1,
+                                            &error)) {
+            g_error ("building menus failed: %s\n", error->message);
+            g_error_free (error);
     }
-#endif /* HAVE_WALLPAPER */
+    gtk_action_group_set_sensitive(window->action_wallpaper, FALSE);
 
     gtk_action_group_set_sensitive(window->actions_collection, FALSE);
     gtk_action_group_set_sensitive(window->actions_image, FALSE);
@@ -1950,11 +2033,12 @@ vnr_window_init (VnrWindow * window)
 
     window->menu_bar = gtk_ui_manager_get_widget (window->ui_mngr, "/MainMenu");
     g_assert(GTK_IS_WIDGET(window->menu_bar));
-    gtk_box_pack_start (GTK_BOX (window->menus), window->menu_bar, FALSE,FALSE,0);
+    gtk_menu_attach_to_widget (GTK_MENU(window->menu_bar), GTK_WIDGET(gtk_ui_manager_get_widget (window->ui_mngr, "/Toolbar/Properties")), NULL);
 
     window->toolbar = gtk_ui_manager_get_widget (window->ui_mngr, "/Toolbar");
     g_assert(GTK_IS_WIDGET(window->toolbar));
     gtk_toolbar_set_style(GTK_TOOLBAR(window->toolbar), GTK_TOOLBAR_ICONS);
+    g_object_set(G_OBJECT(window->toolbar), "show-arrow", FALSE, NULL);
     gtk_toolbar_insert (GTK_TOOLBAR (window->toolbar),
                         GTK_TOOL_ITEM(get_fs_controls(window)), -1);
     gtk_box_pack_start (GTK_BOX (window->menus), window->toolbar, FALSE,FALSE,0);
@@ -1967,13 +2051,20 @@ vnr_window_init (VnrWindow * window)
 
     gtk_widget_hide(get_fs_controls(window));
 
-
+    // Apply toolbar preference
     action = gtk_action_group_get_action (window->action_toolbar,
                                           "ViewToolbar");
     if(!window->prefs->show_toolbar)
         gtk_widget_hide (window->toolbar);
     else
         gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
+        
+    // Apply auto-resize preference
+    action = gtk_action_group_get_action (window->actions_image,
+                                          "ViewResizeWindow");
+
+    if(window->prefs->auto_resize)
+        gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
 
     window->msg_area = vnr_message_area_new();
     VNR_MESSAGE_AREA(window->msg_area)->vnr_win = window;
@@ -2000,7 +2091,7 @@ vnr_window_init (VnrWindow * window)
     vnr_window_set_drag(window);
 
     g_signal_connect (G_OBJECT (window), "destroy",
-                      G_CALLBACK (gtk_main_quit), NULL);
+                      G_CALLBACK (window_destroy_cb), NULL);
 
     g_signal_connect (G_OBJECT (window), "realize",
                       G_CALLBACK (window_realize_cb), NULL);
@@ -2013,6 +2104,9 @@ vnr_window_init (VnrWindow * window)
 
     g_signal_connect (G_OBJECT (window->view), "drag-data-get",
                       G_CALLBACK (window_drag_begin_cb), window);
+                      
+	g_signal_connect (G_OBJECT (window->menu_bar), "hide", 
+					  G_CALLBACK(vnr_window_cmd_main_menu_hidden), window);
 
     gtk_window_add_accel_group (GTK_WINDOW (window),
                 gtk_ui_manager_get_accel_group (window->ui_mngr));
@@ -2057,9 +2151,8 @@ vnr_window_open (VnrWindow * window, gboolean fit_to_screen)
     }
 
     gtk_action_group_set_sensitive(window->actions_image, TRUE);
-#ifdef HAVE_WALLPAPER
     gtk_action_group_set_sensitive(window->action_wallpaper, TRUE);
-#endif /* HAVE_WALLPAPER */
+
 
     format = gdk_pixbuf_get_file_info (file->path, NULL, NULL);
 
@@ -2108,7 +2201,7 @@ vnr_window_open (VnrWindow * window, gboolean fit_to_screen)
 		uni_image_view_set_zoom_mode (UNI_IMAGE_VIEW(window->view), window->prefs->zoom);
     }
 	
-	if ( gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(gtk_action_group_get_action(window->actions_image, "ViewResizeWindow"))) ) {
+	if ( window->prefs->auto_resize ) {
 	    vnr_window_cmd_resize(NULL, window);
 	}
 	
@@ -2185,9 +2278,7 @@ vnr_window_close(VnrWindow *window)
     gtk_window_set_title (GTK_WINDOW (window), "Viewnior");
     uni_anim_view_set_anim (UNI_ANIM_VIEW (window->view), NULL);
     gtk_action_group_set_sensitive(window->actions_image, FALSE);
-#ifdef HAVE_WALLPAPER
     gtk_action_group_set_sensitive(window->action_wallpaper, FALSE);
-#endif /* HAVE_WALLPAPER */
     gtk_action_group_set_sensitive(window->actions_static_image, FALSE);
 }
 
@@ -2196,7 +2287,7 @@ vnr_window_set_list (VnrWindow *window, GList *list, gboolean free_current)
 {
     if (free_current == TRUE && window->file_list != NULL)
         g_list_free (window->file_list);
-    if (g_list_length(g_list_first(list)) != 1)
+    if (g_list_length(g_list_first(list)) > 1)
     {
         gtk_action_group_set_sensitive(window->actions_collection, TRUE);
         allow_slideshow(window);
@@ -2206,7 +2297,6 @@ vnr_window_set_list (VnrWindow *window, GList *list, gboolean free_current)
         gtk_action_group_set_sensitive(window->actions_collection, FALSE);
         deny_slideshow(window);
     }
-    g_assert(list != NULL);
     window->file_list = list;
 }
 
