@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2010 Siyan Panayotov <xsisqox@gmail.com>
+ * Copyright © 2009-2012 Siyan Panayotov <xsisqox@gmail.com>
  *
  * This file is part of Viewnior.
  *
@@ -24,9 +24,6 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include "vnr-prefs.h"
-#ifdef HAVE_WALLPAPER
-#include <gconf/gconf-client.h>
-#endif /* HAVE_WALLPAPER */
 
 G_BEGIN_DECLS
 
@@ -56,6 +53,7 @@ struct _VnrWindow {
     GtkActionGroup *actions_static_image;
     GtkActionGroup *actions_collection;
     GtkActionGroup *action_save;
+    GtkActionGroup *action_properties;
     GtkActionGroup *action_toolbar;
     GtkActionGroup *actions_open_with;
 
@@ -103,10 +101,7 @@ struct _VnrWindow {
     gint ss_timeout;
     GtkWidget *ss_timeout_widget;
 
-#ifdef HAVE_WALLPAPER
-    GConfClient* client;
     GtkActionGroup *action_wallpaper;
-#endif /* HAVE_WALLPAPER */
 };
 
 struct _VnrWindowClass {
